import argparse
import boto3
import json
from datetime import date, datetime
from utils import config_logger, get_glue_tables

# Loading logger config from aux function
logging = config_logger()

def get_tables(catalog_name, max_latency_days=1):

    logging.info("Retrieving information for catalog [ {} ]".format(catalog_name))

    tables_list = get_glue_tables(catalog_name)

    result = {
        "outdated": 0,
        "updated": 0,
        "outdated_list": []
    }
    for table in tables_list:
        table_days_updated = table.get('UpdatedLatency').days
        if table_days_updated > max_latency_days:
            result['outdated'] += 1
            result['outdated_list'].append({
                "table_name": table.get('Name'),
                "due_days": table_days_updated,
                "rows": table.get('recordCount'),
                "last_updated": table.get('UpdateTime'),
            })
            logging.debug("Table {} has latency greather than alowed ({} x {})".format(table.get('Name'), table_days_updated, max_latency_days))
        else:
            result['updated'] += 1

    logging.info("Glue catalog check results:")
    return json.dumps(result, indent=2, default=str)


import io
from os import path
from setuptools import setup, find_packages

MYDIR = path.abspath(path.dirname(__file__))

cmdclass = {}
ext_modules = []

setup(
    name='check_glue_catalog',  
    version='0.1.1',
    author="Marcelo Santino",
    author_email="eu@marcelosantino.com.br",
    description="Check for details in Glue Catalog and tell if its outdated",
    url='https://github.com/msantino/check-glue-catalog',
    long_description=io.open('README.md', 'r', encoding='utf-8').read(),
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    setup_requires=["boto3"],
    cmdclass=cmdclass,
    ext_modules=ext_modules,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
 )


import logging
import sys
import boto3
from datetime import datetime

def config_logger():
    logger = logging.getLogger()
    logger.setLevel(logging.INFO)
    sh = logging.StreamHandler()
    sh.setFormatter(
        logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
    )
    logger.addHandler(sh)
    return logger

def get_table_details(glue_table_spec):
    return {
        "Name": glue_table_spec.get('Name'),
        "CreateTime": glue_table_spec.get('CreateTime').replace(tzinfo=None),
        "UpdateTime": glue_table_spec.get('UpdateTime').replace(tzinfo=None),
        "UpdatedLatency": datetime.now() - glue_table_spec.get('UpdateTime').replace(tzinfo=None),
        "recordCount": glue_table_spec.get('Parameters').get('recordCount'),
    }

def get_glue_tables(DB_NAME, GLUE_MAX_TABLES_RESULT=100):
    
    glue = boto3.client('glue')

    glue_tables = glue.get_tables(
        DatabaseName=DB_NAME,
        MaxResults=GLUE_MAX_TABLES_RESULT
    )

    full_tables_list = list()

    logging.info("Looping glue results")
    for tb in glue_tables.get('TableList'):
        full_tables_list.append(get_table_details(tb))

    next_token=glue_tables.get('NextToken')
    logging.info("Fetching glue tables for NextToken: {}".format(next_token))

    # glue_tables = glue.get_tables(
    #     DatabaseName=DB_NAME,
    #     MaxResults=GLUE_MAX_TABLES_RESULT,
    #     NextToken=next_token
    # )

    logging.info("Glue database tables count: {}".format(len(full_tables_list)))

    return full_tables_list
